System.register([], (function () {
	'use strict';
	return {
		execute: (function () {

			var value = 42;

			console.log('main', value);

		})
	};
}));
